/* GIMP RGBA C-Source image dump 1-byte-run-length-encoded (bnc_cable.c) */

#include "image.h"

static const nv_image_t bnc_cable = {
  64, 64, 4,
  "\224\372\372\372\0\6\371\371\371\0\366\366\366\0\265\265\265\0\356\356\356"
  "\0\273\273\273\0\261\260\261\0\202\332\332\332\0\6\311\311\311\0\225\224"
  "\225\0\256\253\256\0\315\311\315\0\304\302\304\0\216\215\216\0\214\0\0\0"
  "\0\14\11\11\11\1\\\\\\\0fff\0[[[\0TWT\0WUW\0XXX\0WXW\0UUU\0RRR\0MLM\0FFF"
  "\0\206\377\377\377\0\224\372\372\372\0\6\371\371\371\0\366\366\366\0\265"
  "\265\265\0\356\356\356\0\273\273\273\0\261\260\261\0\202\332\332\332\0\6"
  "\311\311\311\0\225\224\225\0\256\253\256\0\315\311\315\0\304\302\304\0\215"
  "\214\215\0\213\0\0\0\0\6\1\1\1\1KKK\14iih\5[\\[\0TTU\0SSS\0\202WWW\0\5US"
  "U\0RPR\0LMM\0FGF\0???\0\206\377\377\377\0\224\372\372\372\0\6\371\371\371"
  "\0\366\366\366\0\265\265\265\0\356\356\356\0\273\273\273\0\261\260\261\0"
  "\202\332\332\332\0\6\311\311\311\0\225\224\225\0\256\253\256\0\315\311\315"
  "\0\304\302\304\0\214\213\214\0\213\0\0\0\0\5=>=!jjj\33\\\\\\\20WUU\10QQS"
  "\1\202UUU\0\6SSU\0RPR\0MMM\0GIG\0@@@\0""888\0\206\377\377\377\0\224\372\372"
  "\372\0\6\371\371\371\0\366\366\366\0\265\265\265\0\356\356\356\0\273\273"
  "\273\0\261\260\261\0\202\332\332\332\0\10\311\311\311\0\225\224\225\0\256"
  "\253\256\0\315\311\315\0\303\301\303\0\211\210\211\0\203\204\203\0\1\1\1"
  "\0\210\0\0\0\0\16&$&/kik7___*WWW\37PQQ\24SSR\14SUS\4RSS\0RPP\0MMM\0GII\0"
  "AC@\0""888\0""777\0\206\377\377\377\0\224\372\372\372\0\6\371\371\371\0\366"
  "\366\366\0\265\265\265\0\356\356\356\0\273\273\273\0\261\260\261\0\202\332"
  "\332\332\0\7\311\311\311\0\225\224\225\0\256\253\256\0\315\311\315\0\303"
  "\301\303\0\207\206\207\0\200\202\200\0\210\0\0\0\0\17\23\23\23*a`aX`aaJX"
  "WW<QRQ0PRP#SSS\31RRS\17PPP\6NMM\0III\0CCC\0:::\0""757\0""899\0\206\377\377"
  "\377\0\224\372\372\372\0\6\371\371\371\0\366\366\366\0\265\265\265\0\356"
  "\356\356\0\273\273\273\0\261\260\261\0\202\332\332\332\0\7\311\311\311\0"
  "\225\224\225\0\256\253\256\0\315\311\315\0\302\300\302\0\207\206\207\0\177"
  "\201\177\0\207\0\0\0\0\20\16\15\16\40XXX|dddmXYX_RPRPPNPBRPR5RRR)PPP\35L"
  "MM\23III\12CCC\3===\0""757\0""888\0===\0\206\377\377\377\0\224\372\372\372"
  "\0\6\371\371\371\0\366\366\366\0\265\265\265\0\356\356\356\0\273\273\273"
  "\0\261\260\261\0\202\332\332\332\0\7\311\311\311\0\225\224\225\0\256\253"
  "\256\0\315\311\315\0\302\300\302\0\207\206\207\0\177\201\177\0\206\0\0\0"
  "\0\21\1\1\1\21KKK\236fff\221YYY\203PPRtNMNePPPVPPPINPN:LLL.III\"CEC\30<="
  "=\16""775\6""777\0;;;\0BBB\0\206\377\377\377\0\224\372\372\372\0\6\371\371"
  "\371\0\366\366\366\0\265\265\265\0\356\356\356\0\273\273\273\0\261\260\261"
  "\0\202\332\332\332\0\7\311\311\311\0\225\224\225\0\256\253\256\0\315\311"
  "\315\0\302\300\302\0\207\206\207\0\177\200\177\0\205\0\0\0\0\22\1\1\1\1>"
  ">>\265fif\265YYY\247RRR\230MMM\211MMNzNNNkNNN]LLLNIII@CCC3==?'777\34""57"
  "5\22""999\11@>>\2;<<\0\206\377\377\377\0\224\372\372\372\0\6\371\371\371"
  "\0\366\366\366\0\265\265\265\0\356\356\356\0\273\273\273\0\261\260\261\0"
  "\202\332\332\332\0\7\311\311\311\0\225\224\225\0\256\253\256\0\315\311\315"
  "\0\302\300\302\0\206\205\206\0~\177~\0\205\0\0\0\0\22""000\261gfg\324ZZZ"
  "\310RRR\273MMM\254MLL\237MMN\217MMM\201JLLqGIIcEEET???G8789555,899\40>>>"
  "\26CBB\15\31\31\31\3\206\377\377\377\0\224\372\372\372\0\6\371\371\371\0"
  "\366\366\366\0\265\265\265\0\356\356\356\0\273\273\273\0\261\260\261\0\202"
  "\332\332\332\0\10\311\311\311\0\225\224\225\0\256\253\256\0\315\311\315\0"
  "\302\300\302\0\206\205\206\0|}|\0ccc\0\203\0\0\0\0\23%%%\244ddf\356\\\\Z"
  "\344RRR\332LLL\316LJL\301MLM\263LLL\245JJJ\226GGG\207CCCx?=?i888[333L888"
  "?;;;1CEC&)))\27\0\0\0\0\206\377\377\377\0\224\372\372\372\0\6\371\371\371"
  "\0\366\366\366\0\265\265\265\0\356\356\356\0\273\273\273\0\261\260\261\0"
  "\202\332\332\332\0\10\311\311\311\0\225\224\225\0\256\253\256\0\315\311\315"
  "\0\302\300\302\0\205\204\205\0{|{\0aaa\0\202\0\0\0\0\24\27\27\27\204aaa\377"
  "\\\\\\\372RRR\363LJL\351III\337JJL\323JJJ\306JIJ\270GGG\252ECC\235???\215"
  "888~333p777a;;;RBBBD6667\0\1\1\4\0\0\0\0\206\377\377\377\0\224\372\372\372"
  "\0\6\371\371\371\0\366\366\366\0\265\265\265\0\356\356\356\0\273\273\273"
  "\0\261\260\261\0\202\332\332\332\0\34\311\311\311\0\225\224\225\0\256\253"
  "\256\0\315\311\315\0\302\300\302\0\205\204\205\0z|z\0```\0\0\0\0\0\17\16"
  "\17_YYY\377^\\\\\377RRR\377LLL\375GGG\366IJI\355JJJ\343III\327FFF\314CCC"
  "\276???\260989\242333\223555\205999v@>@g<><X\12\12\12\32\202\0\0\0\0\206"
  "\377\377\377\0\224\372\372\372\0\6\371\371\371\0\366\366\366\0\265\265\265"
  "\0\356\356\356\0\274\274\274\0\261\260\261\0\202\332\332\332\0\33\311\311"
  "\311\0\225\224\225\0\256\252\256\0\315\311\315\0\302\300\302\0\205\204\205"
  "\0yzy\0^^^\0\1\1\1?QQQ\377^^\\\377PRR\377JII\377FFF\377GGG\377GGI\371GGG"
  "\361FEF\350CCC\335???\321898\304323\267535\251999\232>==\213BBB|\31\31\31"
  "G\203\0\0\0\0\206\377\377\377\0\224\372\372\372\0\"\371\371\371\0\366\366"
  "\366\0\265\265\265\0\357\357\357\0\275\275\275\0\263\261\263\0\334\334\334"
  "\27\334\334\334\31\312\312\312i\225\223\225\230\255\251\255\302\314\310\314"
  "\306\300\276\300\310\202\201\202\302uvu\252XWX\243;<;\365EEE\377BBB\377F"
  "FF\377BBB\377EEE\377FFF\377EFE\377CCC\374@A@\365===\354898\341232\326333"
  "\312888\275===\257ECE\241%''\177\204\0\0\0\0\206\377\377\377\0\225\372\372"
  "\372\0!\367\367\367\0\270\270\270\0\362\362\362\22\300\300\300f\266\265\266"
  "\271\257\257\257\361\237\237\237\377\267\267\267\377\255\255\255\377\325"
  "\325\325\377\302\302\302\377\317\317\317\377\255\255\255\377\256\257\256"
  "\377\236\241\236\377\257\264\257\361\241\244\241\354ccc\366444\376666\377"
  "BDB\377CCA\377AAA\377@??\377===\377989\370222\360232\346888\333;=;\317CC"
  "C\302002\260\1\1\1\4\204\0\0\0\0\206\377\377\377\0\223\372\372\372\0\203"
  "\373\373\373\0\37\275\275\275d\215\215\215\366\177\177\177\377\210\210\210"
  "\377\225\225\225\377\260\260\260\377\253\253\253\377\320\321\320\377\260"
  "\260\260\377\335\336\335\377\274\273\274\376\327\327\327\374\312\313\312"
  "\371\263\264\263\365\330\332\330\361\355\356\355\354\376\377\376\360\307"
  "\310\307\364VWV\374///\377>>>\377===\377;;;\377888\377222\377222\373777\364"
  ";;;\352AAA\340999\325\5\5\4*\205\0\0\0\0\206\377\377\377\0\222\372\372\372"
  "\0\31\373\373\373\0\375\375\375\0\377\377\377\0\301\301\301\250rrr\377uu"
  "u\377\205\205\205\377\223\225\223\377\252\253\252\377\245\245\245\377\312"
  "\312\312\377\245\246\245\377\327\326\327\377\262\261\262\377\276\275\276"
  "\376\331\332\331\376\261\261\261\375\333\333\333\373\302\300\302\373\305"
  "\305\305\373\366\367\366\372\377\377\377\374\352\355\352\375oqo\376323\377"
  "\202777\377\202222\377\5""555\377999\376>@@\367>@>\357\21\20\22f\206\0\0"
  "\0\0\206\377\377\377\0\214\372\372\372\0\205\373\373\373\0\"\374\374\374"
  "\0\375\375\375\0\377\377\377\0\306\306\306\266ttt\377utu\377\201\201\201"
  "\377\216\214\216\377\245\246\245\377\237\236\237\377\304\304\304\377\237"
  "\236\237\377\314\314\314\377\273\272\273\377\256\256\256\377\343\344\343"
  "\377\245\245\245\377\322\322\322\377\317\320\317\376\275\276\275\376\326"
  "\326\326\376\311\311\311\376\323\324\323\376\326\331\326\376\245\247\245"
  "\377MNM\376212\377111\377222\377557\377;99\377>>>\377BCB\377\27\30\27\241"
  "\207\0\0\0\0\206\377\377\377\0\213\363\363\363\0\202\364\364\364\0%\343\341"
  "\343\0\336\336\336\0\356\356\356\0\343\343\343\0\352\352\352\0\341\341\341"
  "\0\326\327\326\202\203\203\203\377ono\377}|}\377\211\210\211\377\244\243"
  "\244\377\234\235\234\377\300\300\300\377\245\243\245\377\300\300\300\377"
  "\311\310\311\377\243\242\243\377\352\352\352\377\261\261\261\377\314\314"
  "\314\377\330\330\330\377\275\276\275\377\325\325\325\377\323\322\323\377"
  "\312\313\312\377\325\326\325\377\317\320\317\377z{z\377CIC\377EIE\377///"
  "\377333\377999\377=>>\377ECE\377$#$\324\210\0\0\0\0\206\377\377\377\0\214"
  "\364\364\364\0&\365\365\365\0\344\342\344\0\337\337\337\0\357\357\357\0\345"
  "\345\345\0\356\356\356\0\347\347\347b\213\213\213\377omo\377~~~\377\214\215"
  "\214\377\247\245\247\377\243\242\243\377\274\274\274\377\261\261\261\377"
  "\265\266\265\377\326\325\326\377\233\234\233\377\350\350\350\377\273\272"
  "\273\377\306\306\306\377\341\341\341\377\306\306\306\377\322\321\322\377"
  "\326\326\326\377\323\324\323\377\324\325\324\377\332\333\332\377\331\332"
  "\331\377\245\247\245\377Y_Y\377`b`\377WWW\377222\377===\377EEE\377000\362"
  "\0\0\0\6\210\0\0\0\0\206\377\377\377\0\214\364\364\364\0%\365\365\365\0\344"
  "\343\344\0\340\340\340\0\360\360\360\0\350\350\350\0\363\363\363P\223\223"
  "\223\377rrr\377\201\201\201\377\224\224\224\377\252\252\252\377\256\256\256"
  "\377\274\274\274\377\300\300\300\377\262\262\262\377\332\332\332\377\231"
  "\230\231\377\340\340\340\377\304\303\304\377\273\273\273\377\343\343\343"
  "\377\312\313\312\377\317\316\317\377\330\330\330\377\331\332\331\377\322"
  "\322\322\377\332\330\332\377\332\333\332\377\317\320\317\377\352\354\352"
  "\377\300\300\300\377ede\377nmn\377HGH\377===\377111\373\1\1\1\32\211\0\0"
  "\0\0\206\377\377\377\0\214\364\364\364\0$\365\365\365\0\344\343\344\0\341"
  "\341\341\0\363\363\363\0\355\355\355<\236\235\236\377{{{\377\214\215\214"
  "\377\244\243\244\377\256\256\256\377\303\303\303\377\277\277\277\377\334"
  "\334\334\377\266\266\266\377\345\345\345\377\247\247\247\377\323\323\323"
  "\377\314\313\314\377\253\252\253\377\340\340\340\377\311\311\311\377\315"
  "\316\315\377\327\325\327\377\334\334\334\377\320\320\320\377\325\325\325"
  "\377\337\336\337\377\321\322\321\377\335\335\335\377\325\325\325\377\303"
  "\303\303\377\306\305\306\377mjm\377NON\377000\376\0\0\0""6\212\0\0\0\0\206"
  "\377\377\377\0\214\364\364\364\0#\365\365\365\0\345\344\345\0\344\344\344"
  "\0\371\371\371-\234\234\234\372nmn\377zyz\377~|~\377olo\377\204\202\204\377"
  "hhh\377\250\246\250\377\220\220\220\377\333\334\333\377\304\304\304\377\326"
  "\325\326\377\340\340\340\377\256\255\256\377\333\332\333\377\310\310\310"
  "\377\304\303\304\377\326\326\326\377\331\332\331\377\324\323\324\377\320"
  "\316\320\377\341\341\341\377\322\322\322\377\325\325\325\377\331\332\331"
  "\377\306\307\306\377\341\341\341\377\311\311\311\377utu\377B@B\377\200\201"
  "\200\306\213\0\0\0\0\206\377\377\377\0\214\364\364\364\0$\366\366\366\0\350"
  "\347\350\0\352\352\3523\216\216\216\361VSV\377TRT\377SQS\377ONO\377dbd\377"
  "trt\377vuv\377ihi\377SRS\377hgh\377\\]\\\377\265\266\265\377\246\246\246"
  "\377\335\335\335\377\327\327\327\377\276\276\276\377\327\330\327\377\323"
  "\324\323\377\324\325\324\377\321\321\321\377\336\340\336\377\326\326\326"
  "\377\320\317\320\377\333\332\333\377\314\314\314\377\327\326\327\377\312"
  "\314\312\377\266\266\266\377\337\340\337\377WWW\377z{z\337\377\377\377\1"
  "\212\0\0\0\0\206\377\377\377\0\213\364\364\364\0%\365\366\365\0\371\372\371"
  "\0\356\355\356@ywy\377EAE\377OMO\377UWU\377][]\377\203\200\203\377\267\264"
  "\267\377\325\322\325\377\312\310\312\377\255\253\255\377\222\222\222\377"
  "\200\202\200\377quq\377]`]\377HKH\377\234\235\234\377\246\247\246\377\337"
  "\337\337\377\332\331\332\377\320\321\320\377\324\324\324\377\334\335\334"
  "\377\330\331\330\377\316\315\316\377\333\332\333\377\323\323\323\377\317"
  "\315\317\377\323\322\323\377\276\277\276\377\332\333\332\377\272\271\272"
  "\377\210\211\210\377nmn\377\341\340\341O\212\0\0\0\0\206\377\377\377\0\211"
  "\364\364\364\0\202\365\365\365\0%\370\370\370\0\377\377\377\33\200|\200\366"
  "858\377VUV\377\211\213\211\377\243\244\243\377\272\271\272\377\320\320\320"
  "\377\330\327\330\377\327\326\327\377\314\312\314\377\267\266\267\377\242"
  "\241\242\377\233\234\233\377\250\257\250\377\276\306\276\377\267\271\267"
  "\377sts\377ILI\377\262\263\262\377\307\307\307\377\333\334\333\377\333\333"
  "\333\377\332\333\332\377\321\321\321\377\332\333\332\377\325\325\325\377"
  "\314\314\314\377\323\323\323\377\306\307\306\377\322\322\322\377\274\274"
  "\274\377\263\263\263\377\333\333\333\377\213\207\213\377\314\310\314\217"
  "\212\0\0\0\0\206\377\377\377\0\211\353\353\353\0(\354\354\354\0\355\355\355"
  "\0\345\343\345\0\237\235\237\266<9<\377nmn\377\305\307\305\377\336\337\336"
  "\377\345\346\345\377\340\342\340\377\325\326\325\377\320\323\320\377\321"
  "\321\321\377\324\323\324\377\336\335\336\377\335\333\335\377\313\312\313"
  "\377\277\304\277\377\321\324\321\377\365\363\365\377\377\377\377\377\307"
  "\310\307\377Z\\Z\377fhf\377\345\344\345\377\341\342\341\377\317\320\317\377"
  "\334\333\334\377\331\332\331\377\311\313\311\377\323\321\323\377\315\315"
  "\315\377\312\311\312\377\310\310\310\377\266\264\266\377\323\324\323\377"
  "\261\261\261\377\266\262\266\377\273\271\273\307\362\362\362\0\211\357\357"
  "\357\0\206\377\377\377\0\211\354\354\354\0(\355\355\355\0\357\357\357\0\350"
  "\347\3508YUY\377\177}\177\377\340\340\340\377\345\345\345\377\322\322\322"
  "\377\265\267\265\377\203\202\203\377}|}\377yzy\377OPO\377QRQ\377\203~\203"
  "\377\260\257\260\377\317\316\317\377\323\322\323\377\316\315\316\377\334"
  "\336\334\377\364\365\364\377\377\377\377\377\335\342\335\377z|z\377hgh\377"
  "\257\260\257\377\350\350\350\377\336\337\336\377\305\306\305\377\326\325"
  "\326\377\317\320\317\377\305\305\305\377\315\314\315\377\273\273\273\377"
  "\325\325\325\377\243\243\243\377\302\301\302\377\301\302\301\377\255\253"
  "\255\332\331\330\331\0\211\327\326\327\0\206\377\377\377\0\211\355\355\355"
  "\0)\356\356\356\0\361\361\361\0\271\270\271\203srs\377\336\340\336\377\341"
  "\341\341\377\256\254\256\377\220\222\220\377nnn\377igi\377wxw\377KLK\377"
  "676\377ROR\377kjk\377\221\225\221\377\303\303\303\377\320\315\320\377\311"
  "\313\311\377\307\311\307\377\323\323\323\377\341\343\341\377\327\334\327"
  "\377\254\256\254\377ORO\377non\377\310\310\310\377\276\277\276\377\322\322"
  "\322\377\326\326\326\377\300\300\300\377\321\320\321\377\300\300\300\377"
  "\316\316\316\377\266\266\266\377\261\261\261\377\301\301\301\377\270\270"
  "\270\377\312\312\312\327\332\332\332\0\330\330\330\0\210\327\327\327\0\206"
  "\377\377\377\0\204\331\330\331\0\3\332\330\332\0\332\331\332\0\332\330\332"
  "\0\202\331\330\331\0(\332\331\332\0\335\334\335\0\222\221\222\311\302\304"
  "\302\377\344\344\344\377\246\244\246\377\203\204\203\377www\377nkn\377}~"
  "}\377WXW\377:<:\377WTW\377trt\377\225\231\225\377\300\301\300\377\320\316"
  "\320\377\307\311\307\377\334\335\334\377\342\341\342\377\312\313\312\377"
  "\317\317\317\377\277\303\277\377rtr\377ORO\377DGD\377MNM\377\303\304\303"
  "\377\350\351\350\377\262\260\262\377\323\321\323\377\300\300\300\377\277"
  "\276\277\377\306\305\306\377\255\255\255\377\313\313\313\377\244\244\244"
  "\377\307\311\307\377\321\323\321\275\374\374\374\0\211\372\372\372\0\206"
  "\377\377\377\0\203\331\331\331\0\1\332\332\332\0\203\333\333\333\0+\332\332"
  "\332\0\331\331\331\0\332\332\332\0\334\334\334\14\273\274\273\345\336\341"
  "\336\377\255\255\255\377\202\203\202\377~\177~\377mjm\377\177\200\177\377"
  "_`_\377;=;\377QQQ\377olo\377\217\221\217\377\272\274\272\377\320\317\320"
  "\377\311\311\311\377\325\330\325\377\361\357\361\377\316\316\316\377\236"
  "\237\236\377\301\302\301\377\322\330\322\377\236\242\236\377>D>\377JNJ\377"
  "YYY\377sts\377\227\227\227\377\311\310\311\377\317\317\317\377\260\260\260"
  "\377\322\321\322\377\252\252\252\377\321\320\321\377\236\237\236\377\302"
  "\303\302\377\273\273\273\377\333\333\333\310\365\365\365\0\363\363\363\0"
  "\210\362\362\362\0\206\377\377\377\0\202\360\360\360\0\6\371\367\371\0\340"
  "\340\340\0\315\315\315\0\316\316\316\0\325\327\325\0\363\363\363\0\202\362"
  "\362\362\0(\364\364\364\7\325\331\325\356\265\264\265\377\202\203\202\377"
  "\202\204\202\377kjk\377\200\177\200\377fgf\377=?=\377POP\377xvx\377\240\243"
  "\240\377\305\307\305\377\327\325\327\377\315\312\315\377\322\323\322\377"
  "\357\356\357\377\332\331\332\377\232\231\232\377\240\240\240\377\311\307"
  "\311\377\316\322\316\377\326\334\326\377\237\244\237\377XYX\377mkm\377PO"
  "P\377\201\201\201\377\336\336\336\377\251\251\251\377\321\320\321\377\246"
  "\247\246\377\304\305\304\377\254\255\254\377\265\265\265\377\275\276\275"
  "\377\301\301\301\377\326\326\326\262\360\360\360\0\356\356\356\0\210\355"
  "\355\355\0\206\377\377\377\0\202\357\357\357\0""0\370\366\370\0\340\340\340"
  "\0\315\315\315\0\317\317\317\0\326\330\326\0\273\274\273\0\350\350\350\0"
  "\377\377\377\0\377\377\377\27\274\275\274\377\203\201\203\377\204\206\204"
  "\377kik\377~~~\377mnm\377=@=\377MNM\377OLO\377545\377[\\[\377\237\235\237"
  "\377\314\311\314\377\342\343\342\377\377\377\377\377\356\354\356\377\247"
  "\247\247\377\244\244\244\377\307\306\307\377\323\324\323\377\276\300\276"
  "\377\302\306\302\377\327\334\327\377\242\244\242\377fbf\377`]`\377UUU\377"
  "xxx\377\316\316\316\377\275\275\275\377\254\256\254\377\300\276\300\377\247"
  "\247\247\377\276\276\276\377\266\266\266\377\271\271\271\377\321\321\321"
  "\276\363\363\363\0\361\361\361\0\210\360\360\360\0\206\377\377\377\0\202"
  "\357\357\357\0/\367\366\367\0\340\340\340\0\315\315\315\0\317\317\317\0\327"
  "\330\327\0\275\276\275\0\354\354\354\0\256\255\256\0\335\335\335M\201\201"
  "\201\377~\177~\377dbd\377rrr\377jkj\377=@=\377GHG\377SOS\377-,-\377GGG\377"
  "AEA\377*-*\377/./\377IJI\377\212\210\212\377\241\240\241\377\272\273\272"
  "\377\327\327\327\377\331\330\331\377\303\303\303\377\266\272\266\377\312"
  "\311\312\377\324\327\324\377\326\334\326\377\213\214\213\377LJL\377HHH\377"
  "non\377\306\306\306\377\264\264\264\377\314\313\314\377\236\236\236\377\304"
  "\303\304\377\262\262\262\377\275\275\275\377\260\260\260\377\320\320\320"
  "\237\364\364\364\0\211\362\362\362\0\206\377\377\377\0\202\357\357\357\0"
  "/\367\366\367\0\340\340\340\0\315\315\315\0\320\320\320\0\331\332\331\0\301"
  "\302\301\0\361\361\361\1\264\263\264U~{~\365\213\214\213\377\236\233\236"
  "\377\241\236\241\377\226\225\226\377Z\\Z\377ACA\377ZVZ\377jij\377\225\230"
  "\225\377\250\255\250\377\301\312\301\377\335\340\335\377\340\341\340\377"
  "\265\265\265\377mnm\377)))\377@@@\377\243\240\243\377\332\333\332\377\310"
  "\314\310\377\304\310\304\377\337\334\337\377\330\326\330\377\314\322\314"
  "\377\311\317\311\377WUW\377CCC\377HKH\377\202\203\202\377\337\336\337\377"
  "\251\250\251\377\277\301\277\377\262\262\262\377\274\274\274\377\256\256"
  "\256\377\243\243\243\377\342\343\342^\337\337\337\0\211\336\336\336\0\206"
  "\377\377\377\0\202\357\357\357\0/\367\366\367\0\340\340\340\0\316\316\316"
  "\0\322\322\322\0\335\336\335\0\306\310\306|\203\205\203\354dad\377}{}\377"
  "\267\265\267\377\326\321\326\377\314\312\314\377\264\262\264\377\233\233"
  "\233\377\221\220\221\377\206\206\206\377\236\241\236\377\271\276\271\377"
  "\254\263\254\377\315\320\315\377\352\353\352\377\375\376\375\377\377\377"
  "\377\377\375\377\375\377\301\302\301\377ILI\377\10\11\10\377,,,\377\230\232"
  "\230\377\361\360\361\377\354\351\354\377\264\265\264\377\247\246\247\377"
  "\331\336\331\377\235\240\235\377FGF\377XXX\377rrr\377\270\270\270\377\306"
  "\306\306\377\275\276\275\377\273\274\273\377\265\267\265\377\231\230\231"
  "\377\240\240\240\377\316\314\316#\314\311\314\0\211\313\310\313\0\206\377"
  "\377\377\0\202\357\357\357\0/\367\366\367\0\340\340\340\0\320\320\320\0\326"
  "\326\326\15\220\222\220\320`b`\377ZWZ\377\177|\177\377\263\263\263\377\317"
  "\314\317\377\305\302\305\377\255\254\255\377\230\231\230\377\225\224\225"
  "\377\233\233\233\377\246\253\246\377\273\303\273\377\323\326\323\377\325"
  "\327\325\377\344\344\344\377\356\354\356\377\344\342\344\377\327\332\327"
  "\377\304\305\304\377~\177~\377WZW\377NSN\377:;:\377\15\15\15\377`^`\377\307"
  "\310\307\377\246\243\246\377\235\234\235\377\307\314\307\377\317\326\317"
  "\377rrr\377|w|\377SSS\377\253\253\253\377\323\323\323\377\273\273\273\377"
  "\272\273\272\377\244\244\244\377|||\377\275\275\275\242\315\312\315\0\313"
  "\311\313\0\211\312\310\312\0\206\377\377\377\0\202\357\357\357\0.\370\367"
  "\370\0\342\342\342\0\322\322\322\4\215\215\215\320TWT\377^\\^\377zxz\377"
  "\253\251\253\377\312\307\312\377\304\301\304\377\254\251\254\377\226\225"
  "\226\377\217\216\217\377\226\226\226\377\237\242\237\377\262\272\262\377"
  "\315\320\315\377\344\344\344\377\360\361\360\377\362\362\362\377\344\343"
  "\344\377\260\257\260\377\241\243\241\377\304\302\304\377\217\221\217\377"
  "FKF\377PQP\377uuu\377kkk\377\24\25\24\377\22\22\22\377\221\220\221\377\310"
  "\314\310\377\325\325\325\377\321\325\321\377\255\255\255\377\235\224\235"
  "\377lll\377}~}\377\313\312\313\377\303\303\303\377\253\253\253\377\205\204"
  "\205\377\210\207\210\364\362\362\362\32\356\356\356\0\212\354\354\354\0\206"
  "\377\377\377\0\202\357\357\357\0.\371\367\371\0\343\343\343\0\217\220\217"
  "\267{}{\377\243\242\243\377\262\262\262\377\301\301\301\377\306\306\306\377"
  "\306\305\306\377\274\274\274\377\253\252\253\377\230\230\230\377\222\222"
  "\222\377\231\235\231\377\256\264\256\377\307\313\307\377\341\337\341\377"
  "\355\355\355\377\360\361\360\377\361\363\361\377\341\345\341\377\264\267"
  "\264\377\305\301\305\377\336\336\336\377\320\321\320\377\256\261\256\377"
  "\215\220\215\377hfh\377XXX\377[[[\377#$#\377\10\12\10\377\276\275\276\377"
  "\357\355\357\377\312\316\312\377\310\312\310\377\256\251\256\377vyv\377n"
  "on\377\324\324\324\377\266\266\266\377\221\220\221\377yxy\377\336\335\336"
  "S\356\356\356\0\353\353\353\0\212\352\352\352\0\206\377\377\377\0""0\357"
  "\357\357\0\360\360\360\0\372\370\372\0\274\275\274\243\260\261\260\377\330"
  "\331\330\377\335\336\335\377\331\333\331\377\326\327\326\377\323\324\323"
  "\377\321\322\321\377\322\321\322\377\323\322\323\377\317\316\317\377\302"
  "\302\302\377\267\272\267\377\303\307\303\377\336\336\336\377\356\356\356"
  "\377\360\361\360\377\360\360\360\377\347\353\347\377\323\331\323\377\252"
  "\254\252\377\233\232\233\377\317\320\317\377\301\302\301\377\306\313\306"
  "\377\351\347\351\377\277\277\277\377Y[Y\377BDB\377ghg\377NJN\377,(,\377\305"
  "\302\305\377\331\333\331\377\314\317\314\377\255\255\255\377~~~\377X[X\377"
  "\270\272\270\377\254\253\254\377usu\377\314\313\314}\331\330\331\0\352\352"
  "\352\0\351\351\351\0\212\350\350\350\0\206\377\377\377\0\7\360\360\360\0"
  "\361\361\361\0\330\331\330\220\311\312\311\377\326\327\326\377\322\323\322"
  "\377\321\322\321\377\203\320\321\320\377\2\320\320\320\377\323\323\323\377"
  "\202\324\323\324\377\36\326\325\326\377\323\322\323\377\317\315\317\377\334"
  "\334\334\377\357\360\357\377\363\364\363\377\352\355\352\377\327\334\327"
  "\377\266\271\266\377~~~\377KMK\377did\377\300\305\300\377\332\333\332\377"
  "\345\341\345\377\314\316\314\377\232\231\232\377ddd\377wrw\377\300\270\300"
  "\377<;<\377FFF\377\346\344\346\377\315\321\315\377\265\265\265\377\212\207"
  "\212\377]`]\377\274\275\274\377\210\207\210\377\246\246\246\301\224\377\377"
  "\377\0\17\355\355\355\0\337\340\337]\306\307\306\377\321\323\321\377\320"
  "\321\320\377\320\320\320\377\320\321\320\377\325\326\325\377\336\337\336"
  "\377\340\341\340\377\335\335\335\377\300\277\300\377\241\241\241\377\301"
  "\300\301\377\310\306\310\377\202\317\316\317\377\33\312\312\312\377\320\317"
  "\320\377\337\343\337\377\333\341\333\377\276\302\276\377\210\211\210\377"
  "_^_\377EKE\377;?;\377\202\205\202\377\354\350\354\377\317\320\317\377\235"
  "\234\235\377\237\235\237\377\276\300\276\377\263\254\263\377\261\256\261"
  "\377Z[Z\377!!!\377\306\306\306\377\321\324\321\377\301\302\301\377\226\227"
  "\226\377WZW\377\234\235\234\377\220\220\220\371\354\353\354\27\224\377\377"
  "\377\0\20\357\357\357\0\316\317\316\347\316\317\316\377\320\321\320\377\320"
  "\320\320\377\322\322\322\377\340\341\340\377\323\324\323\377\244\245\244"
  "\377xyx\377\225\224\225\377\276\276\276\377\252\252\252\377\246\244\246\377"
  "\305\303\305\377\323\323\323\377\202\313\314\313\377\32\314\314\314\377\310"
  "\312\310\377\277\301\277\377\215\217\215\377aba\377KOK\377IMI\377Y\\Y\377"
  "cac\377\236\235\236\377\262\262\262\377\230\224\230\377\260\262\260\377\335"
  "\333\335\377\342\335\342\377\267\264\267\377===\377)))\377\245\250\245\377"
  "\322\325\322\377\317\321\317\377\213\215\213\377Y[Y\377\224\225\224\377\336"
  "\335\336]\351\350\351\0\224\377\377\377\0\23\340\340\340T\312\313\312\377"
  "\320\321\320\377\320\320\320\377\323\322\323\377\343\343\343\377\240\240"
  "\240\377???\377\16\16\16\377\35\35\35\377\246\245\246\377\313\313\313\377"
  "\253\251\253\377\277\275\277\377\344\343\344\377\335\335\335\377\310\310"
  "\310\377\311\311\311\377\314\314\314\377\202\316\317\316\377\27\226\230\226"
  "\377DGD\377@G@\377V[V\377kkk\377pnp\377]]]\377\207\204\207\377\260\262\260"
  "\377\317\322\317\377\340\335\340\377\343\340\343\377\270\270\270\377\15\16"
  "\15\377IJI\377\220\224\220\377\330\332\330\377\312\314\312\377chc\377^`^"
  "\377\302\302\302\255\332\331\332\0\346\345\346\0\224\377\377\377\0-\326\326"
  "\326\246\315\316\315\377\320\320\320\377\321\321\321\377\341\341\341\377"
  "\237\237\237\377\37\35\37\377232\377---\377\235\232\235\377\305\305\305\377"
  "\234\232\234\377\253\247\253\377\332\332\332\377\354\355\354\377\333\335"
  "\333\377\333\333\333\377\323\323\323\377\312\310\312\377\315\313\315\377"
  "\321\320\321\377\331\331\331\377\221\223\221\377INI\377ccc\377sos\377lkl"
  "\377WWW\377UUU\377\302\306\302\377\346\344\346\377\333\325\333\377\340\337"
  "\340\377\255\255\255\377GHG\377JMJ\377\261\262\261\377\334\334\334\377\230"
  "\232\230\377ADA\377z{z\377\377\377\377\31\370\370\370\0\365\365\365\0\364"
  "\364\364\0\215\363\363\363\0\206\377\377\377\0,\322\321\322\302\316\317\316"
  "\377\320\320\320\377\326\326\326\377\321\321\321\377888\377343\377VUV\377"
  "\201\200\201\377\234\236\234\377\250\252\250\377\303\301\303\377\277\277"
  "\277\377\272\273\272\377\270\272\270\377\321\322\321\377\374\374\374\377"
  "\376\376\376\377\335\336\335\377\313\310\313\377\315\314\315\377\322\321"
  "\322\377\333\331\333\377\226\227\226\377eae\377ljl\377bbb\377VUV\377===\377"
  "\223\222\223\377\354\346\354\377\332\330\332\377\315\315\315\377\242\240"
  "\242\377QTQ\377tvt\377\332\333\332\377\307\310\307\377XZX\377HJH\377\320"
  "\320\320|\372\372\372\0\366\366\366\0\365\364\365\0\216\364\364\364\0\206"
  "\377\377\377\0*\323\324\323\300\316\316\316\377\320\320\320\377\335\335\335"
  "\377\250\250\250\377000\377LLL\377rpr\377\234\234\234\377\264\265\264\377"
  "\351\346\351\377\364\365\364\377\362\364\362\377\367\367\367\377\347\345"
  "\347\377\274\274\274\377\321\321\321\377\377\377\377\377\361\363\361\377"
  "\326\325\326\377\311\310\311\377\310\311\310\377\316\317\316\377\322\324"
  "\322\377\217\217\217\377YYY\377YWY\377ONO\377GIG\377gfg\377\332\326\332\377"
  "\331\331\331\377\262\261\262\377aba\377NQN\377\304\305\304\377\334\335\334"
  "\377\214\217\214\377575\377\234\234\234\304\371\372\371\0\362\363\362\0\220"
  "\360\361\360\0\206\377\377\377\0*\334\335\334\240\315\315\315\377\320\320"
  "\320\377\336\335\336\377\232\231\232\377A>A\377ZWZ\377\216\216\216\377\263"
  "\264\263\377\340\337\340\377\357\357\357\377\350\352\350\377\361\362\361"
  "\377\374\372\374\377\377\377\377\377\311\307\311\377\227\226\227\377\247"
  "\250\247\377\343\344\343\377\355\357\355\377\341\340\341\377\304\305\304"
  "\377\305\312\305\377\315\320\315\377\317\323\317\377ppp\377EDE\377MMM\377"
  "XYX\377qpq\377\277\272\277\377\306\304\306\377~~~\377<@<\377\253\255\253"
  "\377\336\337\336\377\255\256\255\377@C@\377\225\226\225\304\366\366\366\12"
  "\364\365\364\0\361\362\361\0\220\360\361\360\0\206\377\377\377\0)\333\335"
  "\333e\315\315\315\377\320\320\320\377\334\332\334\377\243\242\243\377HDH"
  "\377`_`\377\244\245\244\377\334\333\334\377\357\357\357\377\350\351\350\377"
  "\357\361\357\377\372\367\372\377\373\373\373\377\320\317\320\377\256\254"
  "\256\377\204\201\204\377\177}\177\377\275\276\275\377\364\364\364\377\377"
  "\377\377\377\330\331\330\377\301\305\301\377\307\312\307\377\321\330\321"
  "\377\275\277\275\377NNN\377NQN\377ono\377\227\215\227\377\262\254\262\377"
  "\231\232\231\377?@?\377\206\210\206\377\326\327\326\377\257\260\257\377n"
  "pn\377\246\247\246\202\354\354\354\7\361\361\361\0\361\362\361\0\221\360"
  "\361\360\0\206\377\377\377\0)\356\357\356\32\321\321\321\377\316\316\316"
  "\377\331\330\331\377\271\270\271\377NLN\377SSS\377\301\301\301\377\366\365"
  "\366\377\352\353\352\377\355\356\355\377\370\367\370\377\373\372\373\377"
  "\335\336\335\377\256\254\256\377\220\216\220\377tqt\377\353\350\353\377\315"
  "\317\315\377\302\303\302\377\377\377\377\377\353\354\353\377\311\313\311"
  "\377\305\310\305\377\310\314\310\377\326\334\326\377\227\231\227\377YYY\377"
  "\214\204\214\377\254\245\254\377\246\247\246\377SUS\377Z\\Z\377\315\317\315"
  "\377\304\305\304\316\254\255\254\232\313\314\313(\242\243\242\0\351\350\351"
  "\0\357\357\357\0\361\362\361\0\221\360\361\360\0\206\377\377\377\0(\354\355"
  "\354\0\333\333\333\301\313\313\313\377\323\322\323\377\324\321\324\377[["
  "[\377<=<\377\272\272\272\377\372\372\372\377\355\356\355\377\366\365\366"
  "\377\372\367\372\377\346\347\346\377\255\252\255\377\231\227\231\377jgj\377"
  "\323\321\323\377\354\355\354\377\336\337\336\377\274\277\274\377\327\330"
  "\327\377\363\364\363\377\336\337\336\377\305\311\305\377\307\313\307\377"
  "\312\320\312\377\310\312\310\377\211\203\211\377\240\227\240\377\250\251"
  "\250\377\225\225\225\377SUS\377\316\317\316\216\364\365\364A\332\332\332"
  "\0\252\253\252\0\311\312\311\0\240\241\240\0\350\347\350\0\356\356\356\0"
  "\222\360\361\360\0\206\377\377\377\0(\355\353\355\0\357\355\357L\313\312"
  "\313\377\316\315\316\377\337\336\337\377\211\210\211\377\"#\"\377yzy\377"
  "\373\375\373\377\372\371\372\377\370\367\370\377\357\357\357\377\315\315"
  "\315\377\277\274\277\377\204\202\204\377\272\270\272\377\362\362\362\377"
  "\327\330\327\377\350\352\350\377\320\316\320\377\255\257\255\377\366\366"
  "\366\377\331\331\331\377\306\314\306\377\310\315\310\377\307\314\307\377"
  "\314\322\314\377\273\270\273\377\241\237\241\377\232\236\232\377\227\225"
  "\227\377\312\312\312\232\310\311\310\0\360\361\360\0\330\330\330\0\251\252"
  "\251\0\310\311\310\0\240\241\240\0\347\347\347\0\356\356\356\0\222\360\361"
  "\360\0\206\377\377\377\0(\371\370\371\0\373\372\373\0\333\332\333\314\312"
  "\311\312\377\327\326\327\377\314\313\314\377464\377)+)\377\320\316\320\377"
  "\377\377\377\377\357\360\357\377\342\343\342\377\342\344\342\377\320\315"
  "\320\377\315\313\315\377\355\355\355\377\331\332\331\377\343\343\343\377"
  "\342\340\342\377\270\265\270\377\232\232\232\377\334\333\334\377\264\265"
  "\264\377\255\257\255\377\315\322\315\377\306\313\306\377\310\316\310\377"
  "\307\310\307\377\233\235\233\377\227\227\227\377\256\256\256\377\347\350"
  "\347;\343\344\343\0\355\357\355\0\327\327\327\0\250\251\250\0\310\311\310"
  "\0\240\241\240\0\347\347\347\0\356\356\356\0\222\360\361\360\0\206\377\377"
  "\377\0(\370\367\370\0\371\370\371\0\364\363\364<\314\313\314\377\316\315"
  "\316\377\342\341\342\377\223\223\223\377\24\26\24\377_^_\377\363\362\363"
  "\377\357\360\357\377\345\345\345\377\367\370\367\377\374\375\374\377\361"
  "\357\361\377\330\331\330\377\336\337\336\377\347\346\347\377\302\300\302"
  "\377\253\252\253\377\250\251\250\377\272\273\272\377tst\377\\]\\\377\325"
  "\327\325\377\311\314\311\377\310\314\310\377\313\314\313\377\237\235\237"
  "\377\243\241\243\377\275\301\275\377\350\350\350'\346\345\346\0\345\345\345"
  "\0\325\325\325\0\246\250\246\0\307\310\307\0\237\240\237\0\347\347\347\0"
  "\356\356\356\0\222\360\361\360\0\206\377\377\377\0\202\370\367\370\0\36\363"
  "\362\363\0\344\344\344\222\310\310\310\377\321\321\321\377\332\333\332\377"
  "pqp\377%#%\377xwx\377\351\351\351\377\377\377\377\377\376\376\376\377\363"
  "\361\363\377\333\333\333\377\331\334\331\377\351\351\351\377\314\313\314"
  "\377\247\245\247\377\301\302\301\377\261\263\261\377\220\220\220\377\40\37"
  "\40\377KLK\377\326\331\326\377\312\315\312\377\307\311\307\377\311\312\311"
  "\377\254\252\254\377\263\262\263\377\301\303\301\342\367\367\367\0\202\364"
  "\364\364\0\6\365\365\365\0\370\370\370\0\304\306\304\0\236\237\236\0\347"
  "\347\347\0\356\356\356\0\222\360\361\360\0\206\377\377\377\0\202\373\373"
  "\373\0\36\374\374\374\0\376\377\376\0\332\330\332\311\305\310\305\377\322"
  "\324\322\377\326\327\326\377rqr\377111\377rrr\377\354\354\354\377\377\377"
  "\377\377\345\346\345\377\330\333\330\377\351\352\351\377\327\325\327\377"
  "\253\251\253\377\270\270\270\377\312\312\312\377\237\236\237\377III\377\22"
  "\22\22\377^`^\377\327\332\327\377\312\314\312\377\306\307\306\377\305\307"
  "\305\377\274\276\274\377\247\251\247\377\307\307\307x\366\366\366\0\202\363"
  "\363\363\0\6\364\364\364\0\366\366\366\0\302\303\302\0\234\235\234\0\346"
  "\346\346\0\356\356\356\0\222\360\361\360\0\206\377\377\377\0\202\373\373"
  "\373\0&\373\374\373\0\375\375\375\0\365\365\365\12\322\322\322\342\307\310"
  "\307\377\322\324\322\377\323\330\323\377|\200|\377...\377HGH\377\243\240"
  "\243\377\327\327\327\377\363\365\363\377\351\350\351\377\273\271\273\377"
  "\271\270\271\377\316\317\316\377\251\251\251\377ZYZ\377-,-\377\36\35\36\377"
  "\210\210\210\377\327\331\327\377\307\310\307\377\305\306\305\377\307\310"
  "\307\377\262\266\262\377\251\252\251\325\357\357\357\0\354\354\354\0\353"
  "\353\353\0\352\352\352\0\353\353\353\0\354\354\354\0\355\355\355\0\356\356"
  "\356\0\344\344\344\0\355\355\355\0\222\360\361\360\0\206\377\377\377\0\203"
  "\373\373\373\0\26\374\374\374\0\364\364\364\0\366\366\366\34\324\324\324"
  "\347\304\307\304\377\315\322\315\377\324\333\324\377\227\234\227\377545\377"
  "!\36!\377YYY\377\217\216\217\377\244\243\244\377\233\231\233\377\243\243"
  "\243\377\204\205\204\377NMN\377.-.\377\40\37\40\377666\377\304\307\304\377"
  "\315\316\315\377\202\305\306\305\377\4\303\304\303\377\236\237\236\377\336"
  "\336\336*\355\355\355\0\206\353\353\353\0\3\354\354\354\0\343\343\343\0\355"
  "\355\355\0\222\360\361\360\0\206\377\377\377\0\203\373\373\373\0\34\374\374"
  "\374\0\363\363\363\0\364\364\364\0\362\361\362\25\321\325\321\323\302\307"
  "\302\377\310\316\310\377\325\334\325\377\302\306\302\377efe\377///\377=<"
  "=\377<;<\3770/0\377.,.\377'$'\377#\"#\377\36\35\36\377343\377\253\254\253"
  "\377\324\324\324\377\306\307\306\377\305\306\305\377\307\310\307\377\261"
  "\263\261\377\310\311\310q\333\333\333\0\354\354\354\0\207\352\352\352\0\3"
  "\342\342\342\0\354\355\354\0\360\361\360\0\221\357\361\357\0\206\377\377"
  "\377\0\203\373\373\373\0\6\374\374\374\0\362\362\362\0\363\363\363\0\360"
  "\360\360\0\364\363\364\1\332\335\332\241\202\305\312\305\377\6\330\335\330"
  "\377\271\276\271\377<;<\377868\377&$&\377>=>\377\202=;=\377\13MMM\377z|z"
  "\377\301\305\301\377\326\325\326\377\306\310\306\377\305\306\305\377\304"
  "\305\304\377\277\301\277\377\313\314\313\277\372\371\372\0\367\366\367\0"
  "\211\366\365\366\0\1\366\364\366\0\222\365\364\365\0\206\377\377\377\0\203"
  "\373\373\373\0\33\374\374\374\0\362\362\362\0\363\363\363\0\357\357\357\0"
  "\363\362\363\0\330\334\330\0\351\352\351Y\316\321\316\354\304\312\304\377"
  "\321\326\321\377\244\246\244\377DBD\377EDE\377\276\300\276\377\315\321\315"
  "\377\307\313\307\377\320\322\320\377\326\330\326\377\316\320\316\377\307"
  "\307\307\377\306\306\306\377\305\305\305\377\277\300\277\377\311\314\311"
  "\364\370\371\370\22\367\366\367\0\366\365\366\0\234\365\364\365\0\206\377"
  "\377\377\0\203\373\373\373\0\32\374\374\374\0\362\362\362\0\363\363\363\0"
  "\357\357\357\0\363\361\363\0\327\333\327\0\347\350\347\0\347\347\347\15\336"
  "\340\336\213\317\323\317\372\317\323\317\377\306\311\306\377\307\313\307"
  "\377\321\324\321\377\316\320\316\377\315\316\315\377\311\312\311\377\306"
  "\307\306\377\306\306\306\377\307\306\307\377\305\304\305\377\300\300\300"
  "\377\307\307\307\364\355\356\355;\366\367\366\0\366\364\366\0\235\365\364"
  "\365\0\206\377\377\377\0\203\373\373\373\0\20\374\374\374\0\362\362\362\0"
  "\363\363\363\0\357\357\357\0\363\361\363\0\327\333\327\0\347\350\347\0\346"
  "\346\346\0\334\336\334\0\343\344\343\21\337\341\337u\327\331\327\333\314"
  "\316\314\377\305\307\305\377\302\303\302\377\302\302\302\377\202\303\304"
  "\303\377\1\304\302\304\377\202\302\302\302\377\4\325\325\325\267\357\357"
  "\357\36\354\355\354\0\365\366\365\0\236\365\364\365\0\206\377\377\377\0\203"
  "\373\373\373\0\31\374\374\374\0\362\362\362\0\363\363\363\0\357\357\357\0"
  "\363\361\363\0\327\333\327\0\347\350\347\0\346\345\346\0\333\335\333\0\342"
  "\342\342\0\335\337\335\0\360\356\360\0\343\342\343%\343\345\343g\326\325"
  "\326\231\323\324\323\270\314\315\314\314\316\316\316\304\324\324\324\255"
  "\337\340\337q\340\340\340+\323\323\323\0\356\356\356\0\353\354\353\0\365"
  "\366\365\0\236\365\364\365\0\206\377\377\377\0",
};

